@@ -36,6 +36,7 @@ class Hardware(PolymorphicModel):
         MCP3008 = 'MCP3008'
         ModProbe = 'ModProbe'
         PiPico = 'PiPico'
+        Pi = 'Pi'
         VEML7700 = 'VEML7700'
 
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
@@ -61,6 +62,9 @@ class Hardware(PolymorphicModel):
             models.Index(fields=['id']),
         ]
 
+class Pi(Hardware):
+    def __init__(self):
+        super(Hardware,self).__init__()
 
 class PiPico(Hardware):
     serial_com = models.CharField(max_length=100, null=True)
@@ -128,6 +132,7 @@ class Channel(models.Model):
         PiPicoRelay = 'PiPicoRelay'
         VEML7700Light = 'VEML7700Light'
         VEML7700Lux = 'VEML7700Lux'
+        PiRelay = 'PiRelay'
 
     id = models.UUIDField(primary_key=True, default=uuid.uuid4)
     channel_index = models.IntegerField(null=True)
